"""
Form File. This file contains forms for the web application.
"""

from django import forms

from .models import (
    PegModel,
    SectionModel,
    MemberModel,
    TeamsModel
)


class PegForm(forms.ModelForm):
    """
    Form for creating Peg models in the database.
    """
    
    # The number is sort of like the name of the peg
    number = forms.IntegerField(
        label='Peg Number',
        max_value=9,
        min_value=1,
        required=True,
        widget=forms.NumberInput(
            attrs={'style': 'width: 150px;', 'class': 'form-control'}
            )
    )

    class Meta:
        model = PegModel
        fields = ('number',)


class SectionForm(forms.ModelForm):
    """
    Form for creating Section models in the database.
    """
    
    name = forms.CharField(
        label='Section Name',
        max_length=100,
        min_length=1,
        required=True,
        widget=forms.TextInput(
            attrs={'style': 'width: 150px;', 'class': 'form-control'}
        )
    )

    class Meta:
        model = SectionModel
        fields = ('name',)

class MemberForm(forms.ModelForm):
    """
    Form for creating Member models in the database.
    """

    forename = forms.CharField(
        label='First Name',
        max_length=100,
        min_length=1,
        required=True,
        widget=forms.TextInput(
            attrs={'style': 'width: 150px;', 'class': 'form-control'}
        )
    )
    surname = forms.CharField(
        label='Surname',
        max_length=100,
        min_length=1,
        required=True,
        widget=forms.TextInput(
            attrs={'style': 'width: 150px;', 'class': 'form-control'}
        )
    )

    class Meta:
        model = MemberModel
        fields = ('forename', 'surname')


class TeamForm(forms.ModelForm):
    """
    Form for creating Team models in the database.
    """

    # The number is sort of like the name of the team
    number = forms.IntegerField(
        label='Team Number',
        max_value=9999,
        min_value=1,
        required=True,
        widget=forms.NumberInput(
            attrs={'style': 'width: 250px;', 'class': 'form-control my-2'}
        )
    )
    members = forms.ModelMultipleChoiceField(
        queryset=MemberModel.objects.all(),
        required=True,
        widget=forms.CheckboxSelectMultiple
    )
    sections = forms.ModelChoiceField(
        queryset=SectionModel.objects.all(),
        required=True,
        widget=forms.RadioSelect
    )

    class Meta:
        model = TeamsModel
        fields = ()