"""
Models File. This file contains the models for the database.
"""

from django.db import models


class PegModel(models.Model):
    """
    Model for member pegs.
    """
    
    # The number is sort of like the name of the peg
    number = models.IntegerField(unique=True)
    
    def __str__(self):
        return f'Peg #{self.number}'


class SectionModel(models.Model):
    """
    Model for team sections.
    """

    # The name of the section
    name = models.CharField(max_length=100, unique=True)
    
    def __str__(self):
        return f'{self.name}'


class MemberModel(models.Model):
    """
    Model for team members.
    """

    # The member's real name
    forename = models.CharField(max_length=100)
    surname = models.CharField(max_length=100)
    
    def __str__(self):
        return f'{self.forename} {self.surname}'


class TeamsModel(models.Model):
    """
    Model for teams.
    """

    # The number is sort of like the name of the team
    number = models.IntegerField(unique=True)
    
    # List of member IDs
    members = models.ManyToManyField(to=MemberModel)
    
    # Section ID for the team (each team has only one)
    sections = models.OneToOneField(
        to=SectionModel,
        on_delete=models.CASCADE
    )
    
    def __str__(self):
        return f'Team #{self.number}'
